@@ -2,8 +2,8 @@
 
 set -ex
 
-sudo curl -LO https://go.dev/dl/go1.17.4.linux-amd64.tar.gz
+sudo curl -LO https://go.dev/dl/go1.18.linux-amd64.tar.gz
 sudo rm -rf /usr/local/go
-sudo tar -C /usr/local -xzf go1.17.4.linux-amd64.tar.gz
+sudo tar -C /usr/local -xzf go1.18.linux-amd64.tar.gz
 sudo ln -s /usr/local/go/bin/go /usr/local/bin/go
 sudo ln -s /usr/local/go/bin/gofmt /usr/local/bin/gofmt
